Change

Enum Change 

pub enum Change {
Show 13 variants CreateRole { name: String, state: RoleState, }, AlterRole { name: String, attributes: Vec<RoleAttribute>, }, SetComment { name: String, comment: Option<String>, }, Grant { role: String, privileges: BTreeSet<Privilege>, object_type: ObjectType, schema: Option<String>, name: Option<String>, }, Revoke { role: String, privileges: BTreeSet<Privilege>, object_type: ObjectType, schema: Option<String>, name: Option<String>, }, SetDefaultPrivilege { owner: String, schema: String, on_type: ObjectType, grantee: String, privileges: BTreeSet<Privilege>, }, RevokeDefaultPrivilege { owner: String, schema: String, on_type: ObjectType, grantee: String, privileges: BTreeSet<Privilege>, }, AddMember { role: String, member: String, inherit: bool, admin: bool, }, RemoveMember { role: String, member: String, }, ReassignOwned { from_role: String, to_role: String, }, DropOwned { role: String, }, TerminateSessions { role: String, }, DropRole { name: String, },
}
A single change to be applied to the database.

Changes are produced in dependency order by diff:

  1. Create roles (before granting anything to them)
  2. Alter roles (attribute changes)
  3. Grant privileges
  4. Set default privileges
  5. Remove memberships
  6. Add memberships
  7. Revoke default privileges
  8. Revoke privileges
  9. Drop roles (after revoking everything from them)

Variants



CreateRole

Create a new role with the given attributes.

Fields

name: String


AlterRole

Alter an existing role’s attributes.

Fields

name: String
attributes: Vec<RoleAttribute>


SetComment

Update a role’s comment (via COMMENT ON ROLE).

Fields

name: String
comment: Option<String>


Grant

Grant privileges on an object to a role.

Fields

role: String
privileges: BTreeSet<Privilege>
object_type: ObjectType
schema: Option<String>


Revoke

Revoke privileges on an object from a role.

Fields

role: String
privileges: BTreeSet<Privilege>
object_type: ObjectType
schema: Option<String>


SetDefaultPrivilege

Set default privileges (ALTER DEFAULT PRIVILEGES … GRANT …).

Fields

owner: String
schema: String
on_type: ObjectType
grantee: String
privileges: BTreeSet<Privilege>


RevokeDefaultPrivilege

Revoke default privileges (ALTER DEFAULT PRIVILEGES … REVOKE …).

Fields

owner: String
schema: String
on_type: ObjectType
grantee: String
privileges: BTreeSet<Privilege>


AddMember

Grant membership (GRANT role TO member).

Fields

role: String
member: String
inherit: bool
admin: bool


RemoveMember

Revoke membership (REVOKE role FROM member).

Fields

role: String
member: String


ReassignOwned

Reassign owned objects to a successor role before drop.

Fields

from_role: String
to_role: String


DropOwned

Drop owned objects and revoke remaining privileges before drop.

Fields

role: String


TerminateSessions

Terminate other active sessions before dropping a role.

Fields

role: String


DropRole

Drop a role.

Fields

name: String