pub struct ConfigValue(pub String);Expand description
A role configuration parameter value.
Values are always strings — quote numbers and booleans (e.g.
statement_timeout: "30000", jit: "off"). The Kubernetes CRD schema
types config values as strings, and the CLI enforces the same rule so a
manifest means the same thing whether it is applied with pgroles or
kubectl. PostgreSQL coerces the string to the parameter’s type.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ConfigValue
impl Clone for ConfigValue
Sourcefn clone(&self) -> ConfigValue
fn clone(&self) -> ConfigValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigValue
impl Debug for ConfigValue
Sourceimpl<'de> Deserialize<'de> for ConfigValue
impl<'de> Deserialize<'de> for ConfigValue
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigValue
Sourceimpl JsonSchema for ConfigValue
impl JsonSchema for ConfigValue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ConfigValue
impl Ord for ConfigValue
Sourcefn cmp(&self, other: &ConfigValue) -> Ordering
fn cmp(&self, other: &ConfigValue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConfigValue
impl PartialEq for ConfigValue
Sourceimpl PartialOrd for ConfigValue
impl PartialOrd for ConfigValue
Sourceimpl Serialize for ConfigValue
impl Serialize for ConfigValue
impl StructuralPartialEq for ConfigValue