pub struct DefaultPrivilege {
pub owner: Option<String>,
pub schema: String,
pub grant: Vec<DefaultPrivilegeGrant>,
}Expand description
Default privilege configuration.
Fields
owner: Option<String>The role that owns newly created objects. If omitted, uses manifest’s default_owner.
schema: Stringgrant: Vec<DefaultPrivilegeGrant>Trait Implementations
Sourceimpl Clone for DefaultPrivilege
impl Clone for DefaultPrivilege
Sourcefn clone(&self) -> DefaultPrivilege
fn clone(&self) -> DefaultPrivilege
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultPrivilege
impl Debug for DefaultPrivilege
Sourceimpl<'de> Deserialize<'de> for DefaultPrivilege
impl<'de> Deserialize<'de> for DefaultPrivilege
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DefaultPrivilege
impl JsonSchema for DefaultPrivilege
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DefaultPrivilege
impl RefUnwindSafe for DefaultPrivilege
impl Send for DefaultPrivilege
impl Sync for DefaultPrivilege
impl Unpin for DefaultPrivilege
impl UnsafeUnpin for DefaultPrivilege
impl UnwindSafe for DefaultPrivilege