Module sql

Module sql 

SQL generation from Change operations.

Each Change variant is rendered into one or more PostgreSQL DDL statements. All identifiers are double-quoted to handle names containing hyphens, dots, @ signs, etc.

Functions

quote_ident
Double-quote a PostgreSQL identifier, escaping any embedded double quotes.
render
Render a single Change into a SQL statement (including trailing ;).
render_all
Render all changes into a single SQL script.
render_statements
Render a single Change into one or more SQL statements.